import java.util.Vector;

/**
 * Model of a Taxi Garage
 * 
 * @author J. David Fleig 
 * @version July 2005
 */
public class TaxiGarage
{
    protected Vector taxisInGarage;
    protected int garageLocationX;
    protected int garageLocationY;

    /**
     * Constructor for objects of class TaxiGarage
     */
    public TaxiGarage()
    {
        taxisInGarage = new Vector();
        garageLocationX = 0;
        garageLocationY = 0;
        
        for (int i=0 ; i < 10; i++)
        {
            TaxiCab t = createTaxi(i);
            taxisInGarage.add(t);
        }
    }
    /**
     * Gets the x location of the garage
     * 
     * @return The X location of the garage
     */
    public int getGarageLocationX()
    {
        return garageLocationX;
    }
    /**
     * Gets the yx location of the garage
     * 
     * @return The Y location of the garage
     */
    public int getGarageLocationY()
    {
        return garageLocationY;
    }
      /**
     * Determines if there is a taxi available
     * 
     * @return True if and only if there is a taxi available
     */
    public boolean hasTaxiReady()
    {
        return (taxisInGarage.size() > 0);
    }
    /**
     * THe total number of taxis available
     * 
     * @return The number of Taxis that are available
     */
    public int getTaxisAvailable()
    {
        return taxisInGarage.size();
    }
    
    /**
     * Requests a taxi from the garage
     * 
     * @return The requested Taxi
     */
    public TaxiCab getTaxi()
    {
        TaxiCab t = (TaxiCab) taxisInGarage.elementAt(0);
        taxisInGarage.remove(0);
        return t;
    }
     /**
     * Returns a taxi to the garage
     * 
     * @param t The taxi to return to the garage.
     */
    public void returnTaxi(TaxiCab t)
    {
        taxisInGarage.add(t);
    }
    
    private TaxiCab createTaxi(int taxiNumber)
    {
        TaxiCab t = new TaxiCab();
        t.setCabNumber(taxiNumber);
        t.setCurrentLocation(garageLocationX,garageLocationY);
        t.setPickupLocation(TaxiCab.NOWHERE,TaxiCab.NOWHERE);
        t.setDestinationLocation(TaxiCab.NOWHERE,TaxiCab.NOWHERE);
        return t;
    }
    
    
}
