
/**
 * Model of a Taxicab
 * 
 * @author J. David Fleig
 * @version July 2005
 */
public class TaxiCab
{
    public static final int NOWHERE = -1;
    
    protected int cabNumber;
    protected int currentLocationX;
    protected int currentLocationY;
    protected boolean forHire;
    protected boolean havePassenger;
    protected int pickupLocationX;
    protected int pickupLocationY;
    protected int destinationLocationX;
    protected int destinationLocationY;
    protected int dailyTimeInOperation;

    /**
     * Constructor for objects of class TaxiCab
     */
    public TaxiCab()
    {    
        pickupLocationX = NOWHERE;
        pickupLocationY = NOWHERE;
        destinationLocationX = NOWHERE;
        destinationLocationY = NOWHERE;
        dailyTimeInOperation=0;
        forHire=false;
    }
    
    /**
     * Gets the number of minutes since the beginning of the day the cab was last updated.
     * 
     * @return The last time the cab was updated. Time is in minutes since the beginning of the day
     */
    public int getDailyTimeInOperation()
    {
        return dailyTimeInOperation;
    }
    /**
     * Sets the numbers of minutes since the beginning of the day the cab was last updated
     * 
     * @param d The number of minutes since the beginning of the day.
     */
    public void setDailyTimeInOperation(int d)
    {
        dailyTimeInOperation = d;
    }
    /**
     * Gets the cab number.
     * 
     * @return The cab number
     */
    public int getCabNumber()
    {
        return cabNumber;
    }
    /**
     * Sets the cab number
     * 
     * @param num The new cab number.
     */
    public void setCabNumber(int num)
    {
        cabNumber = num;
    }
    
    /**
     * Returns if the cab is for hire or not.
     * 
     * @return True if and only if the cab is currently for hire
     */
    public boolean isForHire()
    {
        return forHire;
    }
    /**
     * Sets whether the cab is for hire or not.
     * 
     * @param b True if and only if the cab is for hire
     */
    public void setForHire(boolean b)
    {
        forHire = b;
    }
    /**
     * Returns if the cab has a passenger.
     * 
     * @return True if and only if the cab has a passenger.
     */
    public boolean hasPassenger()
    {
        return havePassenger;
    }
    /**
     * Sets whether the cab has a passenger.
     * 
     * @param b True if and only if the cab has a passenger.
     */
    public void setHasPassenger(boolean b)
    {
        havePassenger = b;
    }
    /**
     * Returns the cab's current X location
     * 
     * @return the cab's x position
     */
    public int getCurrentLocationX()
    {
        return currentLocationX;
    }
   /**
     * Returns the cab's current Y location
     * 
     * @return the cab's y position
     */
    public int getCurrentLocationY()
    {
        return currentLocationY;
    }
   /**
     * Sets the cab's current location
     * 
     * @param X the cab's x position
     * @param Y the cab's y position
     */
    public void setCurrentLocation(int X, int Y)
    {
        currentLocationX = X;
        currentLocationY = Y;
    }
   /**
     * Returns the cab's pickup X location
     * 
     * @return the cab's pickup x position
     */
    public int getPickupLocationX()
    {
        return pickupLocationX;
    }
    /**
     * Returns the cab's pickup Y location
     * 
     * @return the cab's pickup y position
     */
    public int getPickupLocationY()
    {
        return pickupLocationY;
    }
     /**
     * Sets the cab's pickup location
     * 
     * @param X the cab's pickup x position
     * @param Y the cab's pickup y position
     */
    public void setPickupLocation(int X, int Y)
    {
        pickupLocationX = X;
        pickupLocationY = Y;
    }
    
     /**
     * Returns the cab's destination X location
     * 
     * @return the cab's destination x position
     */
    public int getDestinationLocationX()
    {
        return destinationLocationX;
    }
    /**
     * Returns the cab's destination Y location
     * 
     * @return the cab's destination y position
     */
    public int getDestinationLocationY()
    {
        return destinationLocationY;
    }
    /**
     * Sets the cab's destination location
     * 
     * @param X the cab's destination x position
     * @param Y the cab's destination y position
     */
    public void setDestinationLocation(int X, int Y)
    {
        destinationLocationX = X;
        destinationLocationY = Y;
    }
    
    
    
    
}
