import java.util.Random;
import java.util.Arrays;

/**
 * A suite of utility methods for arrays
 * 
 * @author Todd A. Whittaker
 * @version July 2005
 */
public class ArrayUtilities
{
    /**
     * Creates an array of integer data in sorted order.
     * In particular it creates an increasing sequence of numbers
     * that are between 2 and 102 apart.
     * @param length the length of the array to create
     * @return the generated array
     */
    public static int[] createSortedIntArray(int length)
    {
        assert(length > 0);
        final int DELTA = 100;
        
        Random rand = new Random();        
        int[] arr = new int[length];
        
        arr[0] = rand.nextInt(DELTA);
        for (int i=1; i<length; ++i)
        {
            // ensure that all numbers are unique
            arr[i] = arr[i-1] + rand.nextInt(DELTA) + 2;
        }

        return arr;
    }

    /**
     * Creates an array of random integer data.
     * All numbers in the sequence are unique, and the minimum
     * distance between numbers is 2, while the maximum distance
     * is 102.
     * @param length the length of the array to create
     * @return the generated array
     */
    public static int[] createRandomIntArray(int length)
    {
        return shuffleArray(createSortedIntArray(length));
    }
    
    /**
     * Randomly rearranges the elements in the specified array.
     * @param arr the array to shuffle
     * @return the array randomly shuffled
     */
    public static int[] shuffleArray(int arr[])
    {
        Random rand = new Random();
        for (int i=0; i<arr.length; ++i)
        {
            int index = rand.nextInt(arr.length);

            int temp = arr[i];
            arr[i] = arr[index];
            arr[index] = temp;
        }
        return arr;
    }
}
