import java.util.Map;
import java.util.TreeMap;

/**
 * The test class ArrayUtilitiesTest.
 *
 * @author  Todd A. Whittaker
 * @version July 2005
 */
public class ArrayUtilitiesTest extends junit.framework.TestCase
{
    private static final int MAXLENGTH = 1000;
    
    /**
     * Default constructor for test class ArrayUtilitiesTest
     */
    public ArrayUtilitiesTest()
    {
    }

    /**
     * Sets up the test fixture.
     *
     * Called before every test case method.
     */
    protected void setUp()
    {
    }

    /**
     * Tears down the test fixture.
     *
     * Called after every test case method.
     */
    protected void tearDown()
    {
    }
    
    public void testCreateSortedIntArray()
    {
        int[] arr = ArrayUtilities.createSortedIntArray(MAXLENGTH);
        verifySorted(arr, 0, arr.length);
    }
    
    /**
     * Checks to see if an array is shuffled by creating an array, shuffling
     * it, and checking to see if the shuffled result is a permuation of
     * the original, by not an exact duplicate.
     */
    public void testShuffleArray()
    {
        int[] arr = ArrayUtilities.createSortedIntArray(MAXLENGTH);
        int[] copy = new int[MAXLENGTH];
        System.arraycopy(arr, 0, copy, 0, arr.length);
        ArrayUtilities.shuffleArray(copy);
        verifyPermutation(arr, copy);
        
        boolean different=false;
        for (int i=0; i<arr.length; ++i)
        {
            if (arr[i] != copy[i])
            {
                different = true;
                break;
            }
        }
        assertTrue(different);
    }
    
    /**
     * Checks that the subset of the array is sorted.
     * @param arr the array to test
     * @param left the left bound to begin checking
     * @param right the right bound to end checking (not inclusive)
     */
    private static void verifySorted(int[] arr, int left, int right)
    {
        for (int i=left; i<right-1; ++i)
        {
            assertTrue("Elements out of order at index " + i, arr[i] <= arr[i+1]);
        }
    }
    
    /**
     * Checks that secondArray is a permutation of firstArray
     * @param firstArray the first array to test
     * @param secondArray the second array to test
     */
    private static void verifyPermutation(int[] firstArray, int[] secondArray)
    {
        assertEquals(firstArray.length, secondArray.length);
        Map<Integer, Integer> firstMap = new TreeMap<Integer, Integer>();
        Map<Integer, Integer> secondMap = new TreeMap<Integer, Integer>();
        addToMap(firstMap, firstArray);
        addToMap(secondMap, secondArray);
        assertEquals(firstMap, secondMap);
    }
    
    private static void addToMap(Map<Integer, Integer> map, int[] arr)
    {
        for (int i=0; i<arr.length; ++i)
        {
            Integer count = map.get(arr[i]);
            if (count == null)
            {
                map.put(arr[i], new Integer(1));
            }
            else
            {
                map.put(arr[i], new Integer(1 + count));
            }
        }
    }
}
