/**
 * The test class StopWatchTest.
 *
 * @author  Todd A. Whittaker
 * @version July 2005
 */
public class StopWatchTest extends junit.framework.TestCase
{
    private StopWatch stopWatch = null;
    
    /**
     * Default constructor for test class StopWatchTest
     */
    public StopWatchTest()
    {
    }

    /**
     * Sets up the test fixture.
     *
     * Called before every test case method.
     */
    protected void setUp()
    {
        stopWatch = new StopWatch();
    }

    /**
     * Tears down the test fixture.
     *
     * Called after every test case method.
     */
    protected void tearDown()
    {
    }
    
    /**
     * Checks that the constructor works, and puts the stopwatch in
     * the right initial state
     */
    public void testCreateStopWatch()
    {
        assertNotNull(stopWatch);
        assertFalse(stopWatch.isRunning());
        assertEquals(stopWatch.getElapsedTime(), 0L);
    }
    
    /**
     * Checks that starting and stopping the watch works
     */
    public void testStartingAndStopping()
    {
        stopWatch.start();
        assertTrue(stopWatch.isRunning());
        stopWatch.stop();
        assertFalse(stopWatch.isRunning());
    }
    
    /**
     * Checks that the timer works to within DELTA milliseconds and
     * that the watch can be reset.
     */
    public void testTimingAndResetting()
    {
        final int MILLIS = 100;
        final int DELTA = 50;
        
        stopWatch.start();
        try
        {
            Thread.sleep(MILLIS);
        }
        catch (InterruptedException ignored)
        {
        }
        stopWatch.stop();
        assertTrue(stopWatch.getElapsedTime() >= MILLIS);
        assertTrue(stopWatch.getElapsedTime() <= MILLIS+DELTA);
        
        stopWatch.reset();
        assertFalse(stopWatch.isRunning());
        assertEquals(stopWatch.getElapsedTime(), 0L);

    }
}
