/**
 * The test class InsertionSorterTest.
 *
 * @author  Todd A. Whittaker
 * @version July 2005
 */
public class InsertionSorterTest extends junit.framework.TestCase
{
    private int[] dataToSort;
    private int[] originalData;
    private static final int MAXLENGTH = 1000;
    private static final int LEFT = 300;
    private static final int RIGHT = 700;
    InsertionSorter sorter;
    
    /**
     * Default constructor for test class InsertionSorterTest
     */
    public InsertionSorterTest()
    {
        this.sorter = new InsertionSorter();
    }

    /**
     * Sets up the test fixture.
     *
     * Called before every test case method.
     */
    protected void setUp()
    {
        originalData = ArrayUtilities.createRandomIntArray(MAXLENGTH);
        dataToSort = new int[originalData.length];
        System.arraycopy(originalData, 0, dataToSort, 0, originalData.length);
    }

    /**
     * Tears down the test fixture.
     *
     * Called after every test case method.
     */
    protected void tearDown()
    {
    }
    
    /**
     * Sorts the entire array, and then verifies that it is indeed sorted.
     */
    public void testSortingAll()
    {
        sorter.sort(dataToSort, 0, dataToSort.length);
        verifySorted(dataToSort, 0, dataToSort.length);
    }
    
    /**
     * Sorts only a portion of the array, and verifies that portion is sorted,
     * and that the remainder remains untouched.
     */
    public void testSortingSubset()
    {
        sorter.sort(dataToSort, LEFT, RIGHT);
        verifySorted(dataToSort, LEFT, RIGHT);
        verifyUnchanged(originalData, dataToSort, 0, LEFT);
        verifyUnchanged(originalData, dataToSort, RIGHT, originalData.length);
    }
    
    /**
     * Checks that the subset of the array is sorted.
     * @param arr the array to test
     * @param left the left bound to begin checking
     * @param right the right bound to end checking (not inclusive)
     */
    private static void verifySorted(int[] arr, int left, int right)
    {
        for (int i=left; i<right-1; ++i)
        {
            assertTrue("Elements out of order at index " + i, arr[i] <= arr[i+1]);
        }
    }
    
    /**
     * Checks that the subset of two arrays are equal.
     * @param firstArray the first array to test
     * @param secondArray the second array to test
     * @param left the left bound to begin checking
     * @param right the right bound to end checking (not inclusive)
     */
    private static void verifyUnchanged(int[] firstArray, int[] secondArray, int left, int right)
    {
        for (int i=left; i<right; ++i)
        {
            assertEquals("Mismatch at index " + i, firstArray[i], secondArray[i]);
        }
    }
}
