
/**
 * A class that times the execution of various sorting algorithms
 * 
 * @author Todd A. Whittaker
 * @version July 2003
 */
public class SortTimer
{
    private StopWatch timer;
    
    /**
     * Builds a SortTimer
     */
    public SortTimer()
    {
        this.timer = new StopWatch();
    }
    
    /**
     * Times how long it takes to sort the array the given number of times
     * using the provided sorter object.  The input array is not altered
     * (i.e. it remains unsorted).
     * @param sorter what to use for sorting
     * @param arr the array to sort
     * @param numTimes how many times to sort the data
     * @return the elapsed time for the execution, in milliseconds
     */
    public long timeSort(Sorter sorter, int[] arr, int numTimes)
    {
        int[] arrCopy = new int[arr.length];
        
        for (int i=0; i<numTimes; ++i)
        {
            System.arraycopy(arr, 0, arrCopy, 0, arr.length);
            timer.start();
            sorter.sort(arrCopy, 0, arrCopy.length);
            timer.stop();
        }
        return timer.getElapsedTime();
    }
}
