import java.util.Arrays;

/**
 * The test class SortTimerTest.
 *
 * @author  Todd A. Whittaker
 * @version July 2005
 */
public class SortTimerTest extends junit.framework.TestCase
{
    private SortTimer timer;
    private int[] originalData;
    private int[] dataToSort;
    private static final int MAXLENGTH = 10000;
    
    /**
     * Default constructor for test class SortTimerTest
     */
    public SortTimerTest()
    {
        timer = new SortTimer();
    }

    /**
     * Sets up the test fixture.
     *
     * Called before every test case method.
     */
    protected void setUp()
    {
        originalData = ArrayUtilities.createRandomIntArray(MAXLENGTH);
        dataToSort = new int[originalData.length];
        System.arraycopy(originalData, 0, dataToSort, 0, originalData.length);
    }

    /**
     * Tears down the test fixture.
     *
     * Called after every test case method.
     */
    protected void tearDown()
    {
    }
    
    public void testSortTimer()
    {
        long elapsed = timer.timeSort(new SystemSorter(), dataToSort, 100);
        assertTrue(elapsed > 0L);
        verifyUnchanged(originalData, dataToSort, 0, originalData.length);
    }
    
    
    /**
     * Uses the built in Java Arrays.sort methods to sort an array.
     */
    private class SystemSorter implements Sorter
    {
        public int[] sort(int arr[], int left, int right)
        {
            Arrays.sort(arr, left, right);
            return arr;
        }
    }
    
    /**
     * Checks that the subset of two arrays are equal.
     * @param firstArray the first array to test
     * @param secondArray the second array to test
     * @param left the left bound to begin checking
     * @param right the right bound to end checking (not inclusive)
     */
    private static void verifyUnchanged(int[] firstArray, int[] secondArray, int left, int right)
    {
        for (int i=left; i<right; ++i)
        {
            assertEquals("Mismatch at index " + i, firstArray[i], secondArray[i]);
        }
    }
}
