
/**
 * A millisecond stop watch
 * 
 * @author Todd A. Whittaker
 * @version July 2005
 */
public class StopWatch
{
    /**
     * Build a stop watch in the stopped state, with no elapsed time
     */
    public StopWatch()
    {
        reset();
    }
    
    /**
     * Starts the timer
     */
    public void start()
    {
        if (running)
            return;
        running = true;
        startTime = System.currentTimeMillis();
    }
    
    /**
     * Stops the timer
     */
    public void stop()
    {
        if (!running)
            return;
        running = false;
        long endTime = System.currentTimeMillis();
        elapsedTime = elapsedTime + endTime - startTime;
    }
    
    /**
     * Extract the elapsed time in milliseconds
     * @return elapsed time in milliseconds
     */
    public long getElapsedTime()
    {
        if (running)
        {
            long endTime = System.currentTimeMillis();
            return elapsedTime + endTime - startTime;
        }
        else
            return elapsedTime;
    }
    
    /**
     * Stop the timer and reset to 0 elapsed time
     */
    public void reset()
    {
        elapsedTime = 0;
        running = false;
    }
    
    /**
     * Determine if the stop watch is running
     * @return true when the timer is running, false otherwise
     */
    public boolean isRunning()
    {
        return running;
    }
    
    private long elapsedTime;
    private long startTime;
    private boolean running;
    
    /**
     * String representation of the elapsed time
     */
    public String toString()
    {
        return "" + getElapsedTime();
    }
}
